@@ -1,14 +1,16 @@
 /*
- * GPIO chip test cases for libgpiod.
+ * This file is part of libgpiod.
  *
- * Copyright (C) 2017 Bartosz Golaszewski <bartekgola@gmail.com>
+ * Copyright (C) 2017-2018 Bartosz Golaszewski <bartekgola@gmail.com>
  *
- * This library is free software; you can redistribute it and/or modify it
+ * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation; either version 2.1 of the License, or (at
  * your option) any later version.
  */
 
+/* Test cases for GPIO chip handling. */
+
 #include "gpiod-test.h"
 
 #include <stdio.h>
@@ -31,7 +33,7 @@ static void chip_open_nonexistent(void)
 
 	chip = gpiod_chip_open("/dev/nonexistent_gpiochip");
 	TEST_ASSERT_NULL(chip);
-	TEST_ASSERT_EQ(gpiod_errno(), ENOENT);
+	TEST_ASSERT_ERRNO_IS(ENOENT);
 }
 TEST_DEFINE(chip_open_nonexistent,
 	    "gpiod_chip_open() - nonexistent chip",
@@ -43,7 +45,7 @@ static void chip_open_notty(void)
 
 	chip = gpiod_chip_open("/dev/null");
 	TEST_ASSERT_NULL(chip);
-	TEST_ASSERT_EQ(gpiod_errno(), ENOTTY);
+	TEST_ASSERT_ERRNO_IS(ENOTTY);
 }
 TEST_DEFINE(chip_open_notty,
 	    "gpiod_chip_open() - notty",
@@ -77,13 +79,11 @@ static void chip_open_lookup(void)
 	TEST_CLEANUP(test_close_chip) struct gpiod_chip *chip_by_name = NULL;
 	TEST_CLEANUP(test_close_chip) struct gpiod_chip *chip_by_path = NULL;
 	TEST_CLEANUP(test_close_chip) struct gpiod_chip *chip_by_num = NULL;
-	TEST_CLEANUP(test_free_str) char *chip_num = NULL;
-
-	TEST_ASSERT(asprintf(&chip_num, "%u", test_chip_num(1)) > 0);
 
 	chip_by_name = gpiod_chip_open_lookup(test_chip_name(1));
 	chip_by_path = gpiod_chip_open_lookup(test_chip_path(1));
-	chip_by_num = gpiod_chip_open_lookup(chip_num);
+	chip_by_num = gpiod_chip_open_lookup(
+				test_build_str("%u", test_chip_num(1)));
 	chip_by_label = gpiod_chip_open_lookup("gpio-mockup-B");
 
 	TEST_ASSERT_NOT_NULL(chip_by_name);
@@ -118,7 +118,7 @@ static void chip_open_by_label_bad(void)
 
 	chip = gpiod_chip_open_by_label("nonexistent_gpio_chip");
 	TEST_ASSERT_NULL(chip);
-	TEST_ASSERT_EQ(gpiod_errno(), ENOENT);
+	TEST_ASSERT_ERRNO_IS(ENOENT);
 }
 TEST_DEFINE(chip_open_by_label_bad,
 	    "gpiod_chip_open_by_label() - bad",
@@ -194,3 +194,36 @@ static void chip_num_lines(void)
 TEST_DEFINE(chip_num_lines,
 	    "gpiod_chip_num_lines()",
 	    0, { 1, 4, 8, 16, 32 });
+
+static void chip_find_line_good(void)
+{
+	TEST_CLEANUP(test_close_chip) struct gpiod_chip *chip = NULL;
+	struct gpiod_line *line;
+
+	chip = gpiod_chip_open(test_chip_path(1));
+	TEST_ASSERT_NOT_NULL(chip);
+
+	line = gpiod_chip_find_line(chip, "gpio-mockup-B-4");
+	TEST_ASSERT_NOT_NULL(line);
+	TEST_ASSERT_EQ(gpiod_line_offset(line), 4);
+	TEST_ASSERT_STR_EQ(gpiod_line_name(line), "gpio-mockup-B-4");
+}
+TEST_DEFINE(chip_find_line_good,
+	    "gpiod_chip_find_line() - good",
+	    TEST_FLAG_NAMED_LINES, { 8, 8, 8 });
+
+static void chip_find_line_not_found(void)
+{
+	TEST_CLEANUP(test_close_chip) struct gpiod_chip *chip = NULL;
+	struct gpiod_line *line;
+
+	chip = gpiod_chip_open(test_chip_path(1));
+	TEST_ASSERT_NOT_NULL(chip);
+
+	line = gpiod_chip_find_line(chip, "nonexistent");
+	TEST_ASSERT_NULL(line);
+	TEST_ASSERT_ERRNO_IS(ENOENT);
+}
+TEST_DEFINE(chip_find_line_not_found,
+	    "gpiod_chip_find_line() - not found",
+	    TEST_FLAG_NAMED_LINES, { 8, 8, 8 });
